package com.goldencode.testcases.dmo.p2j_test.impl;

import java.io.Serializable;
import java.util.*;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.testcases.dmo.p2j_test.*;

/**
 * Data Model Object corresponding with table <code>p2j_test.`book`</code>
 * (previously <code>p2j_test.book</code>).
 */
@LegacyTable(name = "book", table = "`book`")
@LegacyIndexes(
{
   @LegacyIndex(name = "book-id", converted = "`book_book_id`",  primary = true),
   @LegacyIndex(name = "author-id", converted = "`book_author_id`"),
   @LegacyIndex(name = "isbn", converted = "`book_isbn`"),
   @LegacyIndex(name = "pub-date", converted = "`book_pub_date`"),
   @LegacyIndex(name = "publisher", converted = "`book_publisher`")
})
public class BookImpl
implements Serializable,
           Persistable,
           Book
{
   /** Surrogate primary key */
   private Long id = null;

   /** Book ID */
   @LegacyField( fieldId = 1 , name = "book-id" , format = "99999999" , initial = "0" , columnLabel = "Book ID" , label = "Book ID" , mandatory = true)
   private final integer bookId;

   /** Title */
   @LegacyField( fieldId = 2 , name = "book-title" , format = "x(35)" , columnLabel = "Title" , label = "Title")
   private final character bookTitle;

   /** Publisher */
   @LegacyField( fieldId = 3 , name = "publisher" , format = "x(20)" , columnLabel = "Publisher" , label = "Publisher")
   private final character publisher;

   /** ISBN */
   @LegacyField( fieldId = 4 , name = "isbn" , format = "x(15)" , columnLabel = "ISBN" , label = "ISBN")
   private final character isbn;

   /** On Hand */
   @LegacyField( fieldId = 5 , name = "on-hand-qty" , format = "99999" , initial = "0" , columnLabel = "On Hand" , label = "On Hand")
   private final integer onHandQty;

   /** Cost */
   @LegacyField( fieldId = 6 , name = "cost" , format = "->>,>>9.99" , initial = "0" , columnLabel = "Cost" , label = "Cost" , validateMessage = "Cost must be greater than 10.00" , validateExpression = "cost > 10.0")
   private final decimal cost;

   /** Pub Date */
   @LegacyField( fieldId = 7 , name = "pub-date" , format = "99/99/9999" , initial = "?" , columnLabel = "Pub Date" , label = "Pub Date")
   private final date pubDate;

   /** Author ID */
   @LegacyField( fieldId = 8 , name = "author-id" , format = "9999999" , initial = "0" , columnLabel = "Author ID" , label = "Author ID")
   private final integer authorId;

   /** Sold */
   @LegacyField( fieldId = 9 , name = "sold-qty" , format = ">,>>9" , initial = "0" , columnLabel = "Sold" , label = "Sold" , validateExpression = "sold-qty > 1")
   private final integer soldQty;

   /** Price */
   @LegacyField( fieldId = 10 , name = "price" , format = "->>,>>9.99" , initial = "0" , columnLabel = "Price" , label = "Price" , validateMessage = "Price must be greater than or equal to cost" , validateExpression = "price >= cost")
   private final decimal price;

   /**
    * Default constructor.
    */
   public BookImpl()
   {
      bookId = new integer(0);
      bookTitle = new character("");
      publisher = new character("");
      isbn = new character("");
      onHandQty = new integer(0);
      cost = new decimal(0, 2);
      pubDate = new date();
      authorId = new integer(0);
      soldQty = new integer(0);
      price = new decimal(0, 2);
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of
    *          this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new BookImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from
    * the given, backup instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      BookImpl from = (BookImpl) old;
      setId(from.getId());
      setBookId(from.getBookId());
      setBookTitle(from.getBookTitle());
      setPublisher(from.getPublisher());
      setIsbn(from.getIsbn());
      setOnHandQty(from.getOnHandQty());
      setCost(from.getCost());
      setPubDate(from.getPubDate());
      setAuthorId(from.getAuthorId());
      setSoldQty(from.getSoldQty());
      setPrice(from.getPrice());
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Book ID
    * 
    * @return  Book ID
    */
   public integer getBookId()
   {
      return (new integer(bookId));
   }

   /**
    * Setter: Book ID
    * 
    * @param   bookId
    *          Book ID
    */
   public void setBookId(NumberType bookId)
   {
      this.bookId.assign(bookId, true);
   }

   /**
    * Getter: Title
    * 
    * @return  Title
    */
   public character getBookTitle()
   {
      return (new character(bookTitle));
   }

   /**
    * Setter: Title
    * 
    * @param   bookTitle
    *          Title
    */
   public void setBookTitle(Text bookTitle)
   {
      this.bookTitle.assign(bookTitle, true);
   }

   /**
    * Getter: Publisher
    * 
    * @return  Publisher
    */
   public character getPublisher()
   {
      return (new character(publisher));
   }

   /**
    * Setter: Publisher
    * 
    * @param   publisher
    *          Publisher
    */
   public void setPublisher(Text publisher)
   {
      this.publisher.assign(publisher, true);
   }

   /**
    * Getter: ISBN
    * 
    * @return  ISBN
    */
   public character getIsbn()
   {
      return (new character(isbn));
   }

   /**
    * Setter: ISBN
    * 
    * @param   isbn
    *          ISBN
    */
   public void setIsbn(Text isbn)
   {
      this.isbn.assign(isbn, true);
   }

   /**
    * Getter: On Hand
    * 
    * @return  On Hand
    */
   public integer getOnHandQty()
   {
      return (new integer(onHandQty));
   }

   /**
    * Setter: On Hand
    * 
    * @param   onHandQty
    *          On Hand
    */
   public void setOnHandQty(NumberType onHandQty)
   {
      this.onHandQty.assign(onHandQty, true);
   }

   /**
    * Getter: Cost
    * 
    * @return  Cost
    */
   public decimal getCost()
   {
      return (new decimal(cost));
   }

   /**
    * Setter: Cost
    * 
    * @param   cost
    *          Cost
    */
   public void setCost(NumberType cost)
   {
      this.cost.assign(cost, true);
   }

   /**
    * Getter: Pub Date
    * 
    * @return  Pub Date
    */
   public date getPubDate()
   {
      return (new date(pubDate));
   }

   /**
    * Setter: Pub Date
    * 
    * @param   pubDate
    *          Pub Date
    */
   public void setPubDate(date pubDate)
   {
      this.pubDate.assign(pubDate, true);
   }

   /**
    * Getter: Author ID
    * 
    * @return  Author ID
    */
   public integer getAuthorId()
   {
      return (new integer(authorId));
   }

   /**
    * Setter: Author ID
    * 
    * @param   authorId
    *          Author ID
    */
   public void setAuthorId(NumberType authorId)
   {
      this.authorId.assign(authorId, true);
   }

   /**
    * Getter: Sold
    * 
    * @return  Sold
    */
   public integer getSoldQty()
   {
      return (new integer(soldQty));
   }

   /**
    * Setter: Sold
    * 
    * @param   soldQty
    *          Sold
    */
   public void setSoldQty(NumberType soldQty)
   {
      this.soldQty.assign(soldQty, true);
   }

   /**
    * Getter: Price
    * 
    * @return  Price
    */
   public decimal getPrice()
   {
      return (new decimal(price));
   }

   /**
    * Setter: Price
    * 
    * @param   price
    *          Price
    */
   public void setPrice(NumberType price)
   {
      this.price.assign(price, true);
   }
}
