package com.goldencode.testcases.dmo.p2j_test.impl;

import java.io.Serializable;
import java.util.*;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.testcases.dmo.p2j_test.*;

/**
 * Data Model Object corresponding with table <code>p2j_test.`customer`</code>
 * (previously <code>p2j_test.customer</code>).
 * <p>
 * table name that conflicts with field names
 */
@LegacyTable(name = "customer", table = "`customer`")
public class CustomerImpl
implements Serializable,
           Persistable,
           Customer
{
   /** Surrogate primary key */
   private Long id = null;

   /** customer's name. */
   @LegacyField( fieldId = 1 , name = "name")
   private final character name;

   /** customer's location. */
   @LegacyField( fieldId = 2 , name = "address")
   private final character address;

   /** customer's balance. */
   @LegacyField( fieldId = 3 , name = "balance" , initial = "0")
   private final integer balance;

   /** Unique field name that doesn't conflict. */
   @LegacyField( fieldId = 4 , name = "unique2" , format = "->,>>>,>>9" , initial = "0")
   private final integer unique2;

   /** field name that conflicts with table and field names */
   @LegacyField( fieldId = 5 , name = "customer" , format = "->,>>>,>>9" , initial = "0")
   private final integer customer;

   /** field name that conflicts with a field name in other tables */
   @LegacyField( fieldId = 6 , name = "description" , format = "99/99/99" , initial = "?")
   private final date description;

   /** conflicts with abbreviation of other field names */
   @LegacyField( fieldId = 7 , name = "uniq" , format = "yes/no" , initial = "false")
   private final logical uniq;

   /**
    * Default constructor.
    */
   public CustomerImpl()
   {
      name = new character("");
      address = new character("");
      balance = new integer(0);
      unique2 = new integer(0);
      customer = new integer(0);
      description = new date();
      uniq = new logical(false);
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of
    *          this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new CustomerImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from
    * the given, backup instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      CustomerImpl from = (CustomerImpl) old;
      setId(from.getId());
      setName(from.getName());
      setAddress(from.getAddress());
      setBalance(from.getBalance());
      setUnique2(from.getUnique2());
      setCustomer(from.getCustomer());
      setDescription(from.getDescription());
      setUniq(from.isUniq());
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: customer's name.
    * 
    * @return  name
    */
   public character getName()
   {
      return (new character(name));
   }

   /**
    * Setter: customer's name.
    * 
    * @param   name
    *          name
    */
   public void setName(Text name)
   {
      this.name.assign(name, true);
   }

   /**
    * Getter: customer's location.
    * 
    * @return  address
    */
   public character getAddress()
   {
      return (new character(address));
   }

   /**
    * Setter: customer's location.
    * 
    * @param   address
    *          address
    */
   public void setAddress(Text address)
   {
      this.address.assign(address, true);
   }

   /**
    * Getter: customer's balance.
    * 
    * @return  balance
    */
   public integer getBalance()
   {
      return (new integer(balance));
   }

   /**
    * Setter: customer's balance.
    * 
    * @param   balance
    *          balance
    */
   public void setBalance(NumberType balance)
   {
      this.balance.assign(balance, true);
   }

   /**
    * Getter: Unique field name that doesn't conflict.
    * 
    * @return  unique2
    */
   public integer getUnique2()
   {
      return (new integer(unique2));
   }

   /**
    * Setter: Unique field name that doesn't conflict.
    * 
    * @param   unique2
    *          unique2
    */
   public void setUnique2(NumberType unique2)
   {
      this.unique2.assign(unique2, true);
   }

   /**
    * Getter: field name that conflicts with table and field names
    * 
    * @return  customer
    */
   public integer getCustomer()
   {
      return (new integer(customer));
   }

   /**
    * Setter: field name that conflicts with table and field names
    * 
    * @param   customer
    *          customer
    */
   public void setCustomer(NumberType customer)
   {
      this.customer.assign(customer, true);
   }

   /**
    * Getter: field name that conflicts with a field name in other tables
    * 
    * @return  description
    */
   public date getDescription()
   {
      return (new date(description));
   }

   /**
    * Setter: field name that conflicts with a field name in other tables
    * 
    * @param   description
    *          description
    */
   public void setDescription(date description)
   {
      this.description.assign(description, true);
   }

   /**
    * Getter: conflicts with abbreviation of other field names
    * 
    * @return  uniq
    */
   public logical isUniq()
   {
      return (new logical(uniq));
   }

   /**
    * Setter: conflicts with abbreviation of other field names
    * 
    * @param   uniq
    *          uniq
    */
   public void setUniq(logical uniq)
   {
      this.uniq.assign(uniq, true);
   }
}
