package com.goldencode.testcases.dmo.p2j_test.impl;

import java.io.Serializable;
import java.util.*;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.testcases.dmo.p2j_test.*;

/**
 * Data Model Object corresponding with table
 * <code>p2j_test.`simple_test`</code> (previously
 * <code>p2j_test.simple</code>).
 */
@LegacyTable(name = "simple", table = "`simple_test`")
@LegacyIndexes(
{
   @LegacyIndex(name = "pi-number", converted = "`simple_test_pi_number`",  primary = true)
})
public class Simple_testImpl
implements Serializable,
           Persistable,
           Simple_test
{
   /** Surrogate primary key */
   private Long id = null;

   /** Number */
   @LegacyField( fieldId = 1 , name = "number" , format = "->,>>>,>>9" , initial = "0" , label = "Number" , mandatory = true)
   private final integer number;

   /** Description */
   @LegacyField( fieldId = 2 , name = "description" , format = "x(24)" , label = "Description")
   private final character description;

   /**
    * Default constructor.
    */
   public Simple_testImpl()
   {
      number = new integer(0);
      description = new character("");
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of
    *          this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new Simple_testImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from
    * the given, backup instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      Simple_testImpl from = (Simple_testImpl) old;
      setId(from.getId());
      setNumber(from.getNumber());
      setDescription(from.getDescription());
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Number
    * 
    * @return  Number
    */
   public integer getNumber()
   {
      return (new integer(number));
   }

   /**
    * Setter: Number
    * 
    * @param   number
    *          Number
    */
   public void setNumber(NumberType number)
   {
      this.number.assign(number, true);
   }

   /**
    * Getter: Description
    * 
    * @return  Description
    */
   public character getDescription()
   {
      return (new character(description));
   }

   /**
    * Setter: Description
    * 
    * @param   description
    *          Description
    */
   public void setDescription(Text description)
   {
      this.description.assign(description, true);
   }
}
