package com.goldencode.testcases.dmo.p2j_test.impl;

import java.io.Serializable;
import java.util.*;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.testcases.dmo.p2j_test.*;

/**
 * Data Model Object corresponding with table
 * <code>p2j_test.vehicle_test</code> (previously
 * <code>p2j_test.vehicle</code>).
 */
@LegacyTable(name = "vehicle", table = "vehicle_test")
@LegacyIndexes(
{
   @LegacyIndex(name = "pi-make-model", converted = "vehicle_test_pi_make_model",  primary = true),
   @LegacyIndex(name = "si-vin", converted = "vehicle_test_si_vin")
})
public class Vehicle_testImpl
implements Serializable,
           Persistable,
           Vehicle_test
{
   /** Surrogate primary key */
   private Long id = null;

   /** Make; Manufacturer */
   @LegacyField( fieldId = 1 , name = "make" , format = "x(12)" , label = "Make" , mandatory = true)
   private final character make;

   /** Model; Vehicle model name */
   @LegacyField( fieldId = 2 , name = "model" , format = "x(16)" , label = "Model" , mandatory = true)
   private final character model;

   /** Number of axles; Number of axles */
   @LegacyField( fieldId = 3 , name = "axles" , format = ">,>>>,>>9" , initial = "2" , label = "Number of axles")
   private final integer axles;

   /** Exterior; Exterior color */
   @LegacyField( fieldId = 4 , name = "ext-color" , format = "x(16)" , label = "Exterior")
   private final character extColor;

   /** VIN; Vehicle Identification Number */
   @LegacyField( fieldId = 5 , name = "vin-number" , format = "xxxx-xxxx-xxxx" , label = "VIN" , mandatory = true)
   private final character vin_number_test;

   /**
    * List of composite properties; 10 elements of type {@link
    * Vehicle_testImpl.Composite10 Composite10}
    */
   private List composite10 = new ArrayList(10);

   /**
    * Default constructor.
    */
   public Vehicle_testImpl()
   {
      make = new character("");
      model = new character("");
      axles = new integer(2);
      extColor = new character("");
      vin_number_test = new character("");
      
      // Populate Composite10 list.
      for (int i = 0; i < 10; i++)
      {
         composite10.add(new Composite10());
      }
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of
    *          this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new Vehicle_testImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from
    * the given, backup instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      Vehicle_testImpl from = (Vehicle_testImpl) old;
      setId(from.getId());
      setMake(from.getMake());
      setModel(from.getModel());
      setAxles(from.getAxles());
      setExtColor(from.getExtColor());
      setVin_number_test(from.getVin_number_test());
      
      // Assign Composite10 properties.
      for (int i = 0; i < 10; i++)
      {
         setOptions(i, from.getOptions(i));
      }
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Manufacturer
    * 
    * @return  Make
    */
   public character getMake()
   {
      return (new character(make));
   }

   /**
    * Setter: Manufacturer
    * 
    * @param   make
    *          Make
    */
   public void setMake(Text make)
   {
      this.make.assign(make, true);
   }

   /**
    * Getter: Vehicle model name
    * 
    * @return  Model
    */
   public character getModel()
   {
      return (new character(model));
   }

   /**
    * Setter: Vehicle model name
    * 
    * @param   model
    *          Model
    */
   public void setModel(Text model)
   {
      this.model.assign(model, true);
   }

   /**
    * Getter: Number of axles
    * 
    * @return  Number of axles
    */
   public integer getAxles()
   {
      return (new integer(axles));
   }

   /**
    * Setter: Number of axles
    * 
    * @param   axles
    *          Number of axles
    */
   public void setAxles(NumberType axles)
   {
      this.axles.assign(axles, true);
   }

   /**
    * Getter: Exterior color
    * 
    * @return  Exterior
    */
   public character getExtColor()
   {
      return (new character(extColor));
   }

   /**
    * Setter: Exterior color
    * 
    * @param   extColor
    *          Exterior
    */
   public void setExtColor(Text extColor)
   {
      this.extColor.assign(extColor, true);
   }

   /**
    * Getter: Vehicle Identification Number
    * 
    * @return  VIN
    */
   public character getVin_number_test()
   {
      return (new character(vin_number_test));
   }

   /**
    * Setter: Vehicle Identification Number
    * 
    * @param   vin_number_test
    *          VIN
    */
   public void setVin_number_test(Text vin_number_test)
   {
      this.vin_number_test.assign(vin_number_test, true);
   }

   /**
    * Indexed Getter: Optional features
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          10</code>).
    * 
    * @return  Options
    */
   public character getOptions(int index)
   {
      return ((Composite10) composite10.get(index)).getOptions();
   }

   /**
    * Getter: Optional features
    * 
    * @return  Options
    */
   public character[] getOptions()
   {
      character[] _options = new character[10];
      for (int i = 0; i < 10; i++)
      {
         _options[i] = getOptions(i);
      }
      return _options;
   }

   /**
    * Indexed Getter: Optional features
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          10</code>).
    * 
    * @return  Options
    */
   public character getOptions(NumberType index)
   {
      return getOptions(index.intValue());
   }

   /**
    * Indexed Setter: Optional features
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          10</code>).
    * @param   element
    *          Options
    */
   public void setOptions(int index, Text element)
   {
      ((Composite10) composite10.get(index)).setOptions(element);
   }

   /**
    * Indexed Setter: Optional features
    * 
    * @param   index
    *          Index of element (where <code>0 &lt;= <em>index</em> &lt;
    *          10</code>).
    * @param   element
    *          Options
    */
   public void setOptions(NumberType index, Text element)
   {
      setOptions(index.intValue(), element);
   }

   /**
    * Set all elements of the target list property to the given scalar value.
    * Modifies the contents of: Optional features
    * 
    * @param   element
    *          Scalar value to which to set all elements of: Options
    */
   public void setOptions(Text element)
   {
      int len = composite10.size();
      for (int i = 0; i < len; i++)
      {
         setOptions(i, element);
      }
   }

   /**
    * Set as many elements of the target list property as are provided in the
    * given array of scalar values. Modifies the contents of: Optional
    * features
    * <p>
    * If the given array is larger than the target list, any additional
    * elements in the given array are ignored. If the target array is smaller
    * than the target list, only those elements whose array indices match are
    * updated.
    * 
    * @param   elements
    *          Array of scalar values to which to set the corresponding
    *          elements of: Options
    */
   public void setOptions(Text[] elements)
   {
      int len = Math.min(elements.length, composite10.size());
      for (int i = 0; i < len; i++)
      {
         setOptions(i, elements[i]);
      }
   }

   /**
    * Report number of list elements for Optional features
    * 
    * @return  Number of list elements for Options
    */
   public integer sizeOptions()
   {
      return (new integer(composite10.size()));
   }

   /**
    * Inner class which composites properties of like extent. All properties
    * migrated from the legacy table <code>p2j_test.vehicle</code> of extent
    * 10 are data members of this class.
    */
   static class Composite10
   implements Serializable
   {
      /** Options; Optional features */
      @LegacyField( fieldId = 6 , name = "options" , format = "x(32)" , label = "Options")
      private final character options;

      /**
       * Default constructor.
       */
      public Composite10()
      {
         options = new character("");
      }

      /**
       * Getter: Optional features
       * 
       * @return  Options
       */
      public character getOptions()
      {
         return (new character(options));
      }

      /**
       * Setter: Optional features
       * 
       * @param   options
       *          Options
       */
      public void setOptions(Text options)
      {
         this.options.assign(options, true);
      }
   }
}
